@@ -1,4 +1,5 @@
 #include "evas_common.h"
+#include "evas_blend_private.h"
 
 static RGBA_Gfx_Func     op_copy_span_funcs[SP_LAST][SM_LAST][SC_LAST][DP_LAST][CPU_LAST];
 static RGBA_Gfx_Pt_Func  op_copy_pt_funcs[SP_LAST][SM_LAST][SC_LAST][DP_LAST][CPU_LAST];
@@ -12,19 +13,19 @@ static RGBA_Gfx_Func op_copy_pixel_color_span_get(RGBA_Image *src, DATA32 col, R
 static RGBA_Gfx_Func op_copy_mask_color_span_get(DATA32 col, RGBA_Image *dst, int pixels);
 static RGBA_Gfx_Func op_copy_pixel_mask_span_get(RGBA_Image *src, RGBA_Image *dst, int pixels);
 
-static RGBA_Gfx_Pt_Func op_copy_pixel_pt_get(int src_flags, RGBA_Image *dst);
+static RGBA_Gfx_Pt_Func op_copy_pixel_pt_get(Image_Entry_Flags src_flags, RGBA_Image *dst);
 static RGBA_Gfx_Pt_Func op_copy_color_pt_get(DATA32 col, RGBA_Image *dst);
-static RGBA_Gfx_Pt_Func op_copy_pixel_color_pt_get(int src_flags, DATA32 col, RGBA_Image *dst);
+static RGBA_Gfx_Pt_Func op_copy_pixel_color_pt_get(Image_Entry_Flags src_flags, DATA32 col, RGBA_Image *dst);
 static RGBA_Gfx_Pt_Func op_copy_mask_color_pt_get(DATA32 col, RGBA_Image *dst);
-static RGBA_Gfx_Pt_Func op_copy_pixel_mask_pt_get(int src_flags, RGBA_Image *dst);
+static RGBA_Gfx_Pt_Func op_copy_pixel_mask_pt_get(Image_Entry_Flags src_flags, RGBA_Image *dst);
 
-static RGBA_Gfx_Compositor  _composite_copy = { "copy", 
- op_copy_init, op_copy_shutdown, 
- op_copy_pixel_span_get, op_copy_color_span_get, 
- op_copy_pixel_color_span_get, op_copy_mask_color_span_get, 
- op_copy_pixel_mask_span_get, 
- op_copy_pixel_pt_get, op_copy_color_pt_get, 
- op_copy_pixel_color_pt_get, op_copy_mask_color_pt_get, 
+static RGBA_Gfx_Compositor  _composite_copy = { "copy",
+ op_copy_init, op_copy_shutdown,
+ op_copy_pixel_span_get, op_copy_color_span_get,
+ op_copy_pixel_color_span_get, op_copy_mask_color_span_get,
+ op_copy_pixel_mask_span_get,
+ op_copy_pixel_pt_get, op_copy_color_pt_get,
+ op_copy_pixel_color_pt_get, op_copy_mask_color_pt_get,
  op_copy_pixel_mask_pt_get
  };
 
@@ -47,19 +48,21 @@ static RGBA_Gfx_Func op_copy_rel_pixel_color_span_get(RGBA_Image *src, DATA32 co
 static RGBA_Gfx_Func op_copy_rel_mask_color_span_get(DATA32 col, RGBA_Image *dst, int pixels);
 static RGBA_Gfx_Func op_copy_rel_pixel_mask_span_get(RGBA_Image *src, RGBA_Image *dst, int pixels);
 
-static RGBA_Gfx_Pt_Func op_copy_rel_pixel_pt_get(int src_flags, RGBA_Image *dst);
+static RGBA_Gfx_Pt_Func op_copy_rel_pixel_pt_get(Image_Entry_Flags src_flags, RGBA_Image *dst);
+/* XXX: doesn't exist
 static RGBA_Gfx_Pt_Func op_copy_rel_color_pt_get(DATA32 col, RGBA_Image *dst);
-static RGBA_Gfx_Pt_Func op_copy_rel_pixel_color_pt_get(int src_flags, DATA32 col, RGBA_Image *dst);
+ */
+static RGBA_Gfx_Pt_Func op_copy_rel_pixel_color_pt_get(Image_Entry_Flags src_flags, DATA32 col, RGBA_Image *dst);
 static RGBA_Gfx_Pt_Func op_copy_rel_mask_color_pt_get(DATA32 col, RGBA_Image *dst);
-static RGBA_Gfx_Pt_Func op_copy_rel_pixel_mask_pt_get(int src_flags, RGBA_Image *dst);
+static RGBA_Gfx_Pt_Func op_copy_rel_pixel_mask_pt_get(Image_Entry_Flags src_flags, RGBA_Image *dst);
 
-static RGBA_Gfx_Compositor  _composite_copy_rel = { "copy_rel", 
- op_copy_rel_init, op_copy_rel_shutdown, 
- op_copy_rel_pixel_span_get, op_copy_rel_color_span_get, 
- op_copy_rel_pixel_color_span_get, op_copy_rel_mask_color_span_get, 
- op_copy_rel_pixel_mask_span_get, 
- op_copy_rel_pixel_pt_get, op_copy_color_pt_get, 
- op_copy_rel_pixel_color_pt_get, op_copy_rel_mask_color_pt_get, 
+static RGBA_Gfx_Compositor  _composite_copy_rel = { "copy_rel",
+ op_copy_rel_init, op_copy_rel_shutdown,
+ op_copy_rel_pixel_span_get, op_copy_rel_color_span_get,
+ op_copy_rel_pixel_color_span_get, op_copy_rel_mask_color_span_get,
+ op_copy_rel_pixel_mask_span_get,
+ op_copy_rel_pixel_pt_get, op_copy_color_pt_get,
+ op_copy_rel_pixel_color_pt_get, op_copy_rel_mask_color_pt_get,
  op_copy_rel_pixel_mask_pt_get
  };
 
@@ -84,6 +87,13 @@ evas_common_gfx_compositor_copy_rel_get(void)
 # include "./evas_op_copy/op_copy_mask_color_i386.c"
 //# include "./evas_op_copy/op_copy_pixel_mask_color_i386.c"
 
+# include "./evas_op_copy/op_copy_pixel_neon.c"
+# include "./evas_op_copy/op_copy_color_neon.c"
+# include "./evas_op_copy/op_copy_pixel_color_neon.c"
+# include "./evas_op_copy/op_copy_pixel_mask_neon.c"
+# include "./evas_op_copy/op_copy_mask_color_neon.c"
+//# include "./evas_op_copy/op_copy_pixel_mask_color_neon.c"
+
 
 static void
 op_copy_init(void)
@@ -103,6 +113,19 @@ op_copy_init(void)
    init_copy_color_pt_funcs_mmx();
    init_copy_mask_color_pt_funcs_mmx();
 #endif
+#ifdef BUILD_NEON
+   init_copy_pixel_span_funcs_neon();
+   init_copy_pixel_color_span_funcs_neon();
+   init_copy_pixel_mask_span_funcs_neon();
+   init_copy_color_span_funcs_neon();
+   init_copy_mask_color_span_funcs_neon();
+
+   init_copy_pixel_pt_funcs_neon();
+   init_copy_pixel_color_pt_funcs_neon();
+   init_copy_pixel_mask_pt_funcs_neon();
+   init_copy_color_pt_funcs_neon();
+   init_copy_mask_color_pt_funcs_neon();
+#endif
 #ifdef BUILD_C
    init_copy_pixel_span_funcs_c();
    init_copy_pixel_color_span_funcs_c();
@@ -136,6 +159,14 @@ copy_gfx_span_func_cpu(int s, int m, int c, int d)
       if (func) return func;
     }
 #endif
+#ifdef BUILD_NEON
+   if (evas_common_cpu_has_feature(CPU_FEATURE_NEON))
+    {
+      cpu = CPU_NEON;
+      func = op_copy_span_funcs[s][m][c][d][cpu];
+      if (func) return func;
+    }
+#endif
 #ifdef BUILD_C
    cpu = CPU_C;
    func = op_copy_span_funcs[s][m][c][d][cpu];
@@ -145,73 +176,73 @@ copy_gfx_span_func_cpu(int s, int m, int c, int d)
 }
 
 static RGBA_Gfx_Func
-op_copy_pixel_span_get(RGBA_Image *src, RGBA_Image *dst, int pixels)
+op_copy_pixel_span_get(RGBA_Image *src, RGBA_Image *dst, int pixels __UNUSED__)
 {
    int  s = SP_AN, m = SM_N, c = SC_N, d = DP_AN;
 
-   if (src && (src->flags & RGBA_IMAGE_HAS_ALPHA))
+   if (src && src->cache_entry.flags.alpha)
      {
-	dst->flags |= RGBA_IMAGE_HAS_ALPHA;
+	dst->cache_entry.flags.alpha = 1;
 	s = SP;
      }
-   if (dst && (dst->flags & RGBA_IMAGE_HAS_ALPHA))
+   if (dst && dst->cache_entry.flags.alpha)
 	d = DP;
    return copy_gfx_span_func_cpu(s, m, c, d);
 }
 
 static RGBA_Gfx_Func
-op_copy_color_span_get(DATA32 col, RGBA_Image *dst, int pixels)
+op_copy_color_span_get(DATA32 col, RGBA_Image *dst, int pixels __UNUSED__)
 {
    int  s = SP_N, m = SM_N, c = SC_AN, d = DP_AN;
 
    if ((col >> 24) < 255)
      {
 	if (dst)
-	   dst->flags |= RGBA_IMAGE_HAS_ALPHA;
+	   dst->cache_entry.flags.alpha = 1;
 	c = SC;
      }
    if (col == ((col >> 24) * 0x01010101))
 	c = SC_AA;
    if (col == 0xffffffff)
 	c = SC_N;
-   if (dst && (dst->flags & RGBA_IMAGE_HAS_ALPHA))
+   if (dst && dst->cache_entry.flags.alpha)
 	d = DP;
    return copy_gfx_span_func_cpu(s, m, c, d);
 }
 
 static RGBA_Gfx_Func
-op_copy_pixel_color_span_get(RGBA_Image *src, DATA32 col, RGBA_Image *dst, int pixels)
+op_copy_pixel_color_span_get(RGBA_Image *src, DATA32 col, RGBA_Image *dst, int pixels __UNUSED__)
 {
    int  s = SP_AN, m = SM_N, c = SC_AN, d = DP_AN;
 
-   if (src && (src->flags & RGBA_IMAGE_HAS_ALPHA))
+   if (src && src->cache_entry.flags.alpha)
      {
 	if (dst)
-	   dst->flags |= RGBA_IMAGE_HAS_ALPHA;
+	   dst->cache_entry.flags.alpha = 1;
 	s = SP;
      }
    if ((col >> 24) < 255)
      {
 	if (dst)
-	   dst->flags |= RGBA_IMAGE_HAS_ALPHA;
+	   dst->cache_entry.flags.alpha = 1;
 	c = SC;
      }
    if (col == ((col >> 24) * 0x01010101))
 	c = SC_AA;
    if (col == 0xffffffff)
 	c = SC_N;
-   if (dst && (dst->flags & RGBA_IMAGE_HAS_ALPHA))
+   if (dst && dst->cache_entry.flags.alpha)
 	d = DP;
    return copy_gfx_span_func_cpu(s, m, c, d);
 }
 
 static RGBA_Gfx_Func
-op_copy_mask_color_span_get(DATA32 col, RGBA_Image *dst, int pixels)
+op_copy_mask_color_span_get(DATA32 col, RGBA_Image *dst, int pixels __UNUSED__)
 {
    int  s = SP_N, m = SM_AS, c = SC_AN, d = DP;
 
    if (dst)
-	dst->flags |= RGBA_IMAGE_HAS_ALPHA;
+	dst->cache_entry.flags.alpha = 1;
    if ((col >> 24) < 255)
 	c = SC;
    if (col == ((col >> 24) * 0x01010101))
@@ -222,18 +253,18 @@ op_copy_mask_color_span_get(DATA32 col, RGBA_Image *dst, int pixels)
 }
 
 static RGBA_Gfx_Func
-op_copy_pixel_mask_span_get(RGBA_Image *src, RGBA_Image *dst, int pixels)
+op_copy_pixel_mask_span_get(RGBA_Image *src, RGBA_Image *dst, int pixels __UNUSED__)
 {
    int  s = SP_AN, m = SM_AS, c = SC_N, d = DP;
 
    if (dst)
-	dst->flags |= RGBA_IMAGE_HAS_ALPHA;
-   if (src && (src->flags & RGBA_IMAGE_HAS_ALPHA))
+	dst->cache_entry.flags.alpha = 1;
+   if (src && src->cache_entry.flags.alpha)
 	s = SP;
    return copy_gfx_span_func_cpu(s, m, c, d);
 }
 
-static RGBA_Gfx_Pt_Func 
+static RGBA_Gfx_Pt_Func
 copy_gfx_pt_func_cpu(int s, int m, int c, int d)
 {
    RGBA_Gfx_Pt_Func  func = NULL;
@@ -246,6 +277,14 @@ copy_gfx_pt_func_cpu(int s, int m, int c, int d)
       if (func) return func;
     }
 #endif
+#ifdef BUILD_NEON
+   if (evas_common_cpu_has_feature(CPU_FEATURE_NEON))
+    {
+      cpu = CPU_NEON;
+      func = op_copy_pt_funcs[s][m][c][d][cpu];
+      if (func) return func;
+    }
+#endif
 #ifdef BUILD_C
    cpu = CPU_C;
    func = op_copy_pt_funcs[s][m][c][d][cpu];
@@ -255,16 +294,16 @@ copy_gfx_pt_func_cpu(int s, int m, int c, int d)
 }
 
 static RGBA_Gfx_Pt_Func
-op_copy_pixel_pt_get(int src_flags, RGBA_Image *dst)
+op_copy_pixel_pt_get(Image_Entry_Flags src_flags, RGBA_Image *dst)
 {
    int  s = SP_AN, m = SM_N, c = SC_N, d = DP_AN;
 
-   if (src_flags & RGBA_IMAGE_HAS_ALPHA)
+   if (src_flags.alpha)
      {
-	dst->flags |= RGBA_IMAGE_HAS_ALPHA;
+	dst->cache_entry.flags.alpha = 1;
 	s = SP;
      }
-   if (dst && (dst->flags & RGBA_IMAGE_HAS_ALPHA))
+   if (dst && dst->cache_entry.flags.alpha)
 	d = DP;
    return copy_gfx_pt_func_cpu(s, m, c, d);
 }
@@ -277,40 +316,40 @@ op_copy_color_pt_get(DATA32 col, RGBA_Image *dst)
    if ((col >> 24) < 255)
      {
 	if (dst)
-	   dst->flags |= RGBA_IMAGE_HAS_ALPHA;
+	   dst->cache_entry.flags.alpha = 1;
 	c = SC;
      }
    if (col == ((col >> 24) * 0x01010101))
 	c = SC_AA;
    if (col == 0xffffffff)
 	c = SC_N;
-   if (dst && (dst->flags & RGBA_IMAGE_HAS_ALPHA))
+   if (dst && dst->cache_entry.flags.alpha)
 	d = DP;
    return copy_gfx_pt_func_cpu(s, m, c, d);
 }
 
 static RGBA_Gfx_Pt_Func
-op_copy_pixel_color_pt_get(int src_flags, DATA32 col, RGBA_Image *dst)
+op_copy_pixel_color_pt_get(Image_Entry_Flags src_flags, DATA32 col, RGBA_Image *dst)
 {
    int  s = SP_AN, m = SM_N, c = SC_AN, d = DP_AN;
 
-   if (src_flags & RGBA_IMAGE_HAS_ALPHA)
+   if (src_flags.alpha)
      {
 	if (dst)
-	   dst->flags |= RGBA_IMAGE_HAS_ALPHA;
+	   dst->cache_entry.flags.alpha = 1;
 	s = SP;
      }
    if ((col >> 24) < 255)
      {
 	if (dst)
-	   dst->flags |= RGBA_IMAGE_HAS_ALPHA;
+	   dst->cache_entry.flags.alpha = 1;
 	c = SC;
      }
    if (col == ((col >> 24) * 0x01010101))
 	c = SC_AA;
    if (col == 0xffffffff)
 	c = SC_N;
-   if (dst && (dst->flags & RGBA_IMAGE_HAS_ALPHA))
+   if (dst && dst->cache_entry.flags.alpha)
 	d = DP;
    return copy_gfx_pt_func_cpu(s, m, c, d);
 }
@@ -321,7 +360,7 @@ op_copy_mask_color_pt_get(DATA32 col, RGBA_Image *dst)
    int  s = SP_N, m = SM_AS, c = SC_AN, d = DP;
 
    if (dst)
-	dst->flags |= RGBA_IMAGE_HAS_ALPHA;
+	dst->cache_entry.flags.alpha = 1;
    if ((col >> 24) < 255)
 	c = SC;
    if (col == ((col >> 24) * 0x01010101))
@@ -332,13 +371,13 @@ op_copy_mask_color_pt_get(DATA32 col, RGBA_Image *dst)
 }
 
 static RGBA_Gfx_Pt_Func
-op_copy_pixel_mask_pt_get(int src_flags, RGBA_Image *dst)
+op_copy_pixel_mask_pt_get(Image_Entry_Flags src_flags, RGBA_Image *dst)
 {
    int  s = SP_AN, m = SM_AS, c = SC_N, d = DP;
 
    if (dst)
-	dst->flags |= RGBA_IMAGE_HAS_ALPHA;
-   if (src_flags & RGBA_IMAGE_HAS_ALPHA)
+	dst->cache_entry.flags.alpha = 1;
+   if (src_flags.alpha)
 	s = SP;
    return copy_gfx_pt_func_cpu(s, m, c, d);
 }
@@ -362,6 +401,19 @@ op_copy_rel_init(void)
    init_copy_rel_color_pt_funcs_mmx();
    init_copy_rel_mask_color_pt_funcs_mmx();
 #endif
+#ifdef BUILD_NEON
+   init_copy_rel_pixel_span_funcs_neon();
+   init_copy_rel_pixel_color_span_funcs_neon();
+   init_copy_rel_pixel_mask_span_funcs_neon();
+   init_copy_rel_color_span_funcs_neon();
+   init_copy_rel_mask_color_span_funcs_neon();
+
+   init_copy_rel_pixel_pt_funcs_neon();
+   init_copy_rel_pixel_color_pt_funcs_neon();
+   init_copy_rel_pixel_mask_pt_funcs_neon();
+   init_copy_rel_color_pt_funcs_neon();
+   init_copy_rel_mask_color_pt_funcs_neon();
+#endif
 #ifdef BUILD_C
    init_copy_rel_pixel_span_funcs_c();
    init_copy_rel_pixel_color_span_funcs_c();
@@ -395,6 +447,14 @@ copy_rel_gfx_span_func_cpu(int s, int m, int c, int d)
       if (func) return func;
     }
 #endif
+#ifdef BUILD_NEON
+   if (evas_common_cpu_has_feature(CPU_FEATURE_NEON))
+    {
+      cpu = CPU_NEON;
+      func = op_copy_rel_span_funcs[s][m][c][d][cpu];
+      if (func) return func;
+    }
+#endif
 #ifdef BUILD_C
    cpu = CPU_C;
    func = op_copy_rel_span_funcs[s][m][c][d][cpu];
@@ -404,74 +464,74 @@ copy_rel_gfx_span_func_cpu(int s, int m, int c, int d)
 }
 
 static RGBA_Gfx_Func
-op_copy_rel_pixel_span_get(RGBA_Image *src, RGBA_Image *dst, int pixels)
+op_copy_rel_pixel_span_get(RGBA_Image *src, RGBA_Image *dst, int pixels __UNUSED__)
 {
    int  s = SP_AN, m = SM_N, c = SC_N, d = DP_AN;
 
-   if (src && (src->flags & RGBA_IMAGE_HAS_ALPHA))
+   if (src && src->cache_entry.flags.alpha)
      {
 	if (dst)
-	   dst->flags |= RGBA_IMAGE_HAS_ALPHA;
+	   dst->cache_entry.flags.alpha = 1;
 	s = SP;
      }
-   if (dst && (dst->flags & RGBA_IMAGE_HAS_ALPHA))
+   if (dst && dst->cache_entry.flags.alpha)
 	d = DP;
    return copy_rel_gfx_span_func_cpu(s, m, c, d);
 }
 
 static RGBA_Gfx_Func
-op_copy_rel_color_span_get(DATA32 col, RGBA_Image *dst, int pixels)
+op_copy_rel_color_span_get(DATA32 col, RGBA_Image *dst, int pixels __UNUSED__)
 {
    int  s = SP_N, m = SM_N, c = SC_AN, d = DP_AN;
 
    if ((col >> 24) < 255)
      {
 	if (dst)
-	   dst->flags |= RGBA_IMAGE_HAS_ALPHA;
+	   dst->cache_entry.flags.alpha = 1;
 	c = SC;
      }
    if (col == ((col >> 24) * 0x01010101))
 	c = SC_AA;
    if (col == 0xffffffff)
 	c = SC_N;
-   if (dst && (dst->flags & RGBA_IMAGE_HAS_ALPHA))
+   if (dst && dst->cache_entry.flags.alpha)
 	d = DP;
    return copy_rel_gfx_span_func_cpu(s, m, c, d);
 }
 
 static RGBA_Gfx_Func
-op_copy_rel_pixel_color_span_get(RGBA_Image *src, DATA32 col, RGBA_Image *dst, int pixels)
+op_copy_rel_pixel_color_span_get(RGBA_Image *src, DATA32 col, RGBA_Image *dst, int pixels __UNUSED__)
 {
    int  s = SP_AN, m = SM_N, c = SC_AN, d = DP_AN;
 
-   if (src && (src->flags & RGBA_IMAGE_HAS_ALPHA))
+   if (src && src->cache_entry.flags.alpha)
      {
 	if (dst)
-	   dst->flags |= RGBA_IMAGE_HAS_ALPHA;
+	   dst->cache_entry.flags.alpha = 1;
 	s = SP;
      }
    if ((col >> 24) < 255)
      {
 	if (dst)
-	   dst->flags |= RGBA_IMAGE_HAS_ALPHA;
+	   dst->cache_entry.flags.alpha = 1;
 	c = SC;
      }
    if (col == ((col >> 24) * 0x01010101))
 	c = SC_AA;
    if (col == 0xffffffff)
 	c = SC_N;
-   if (dst && (dst->flags & RGBA_IMAGE_HAS_ALPHA))
+   if (dst && dst->cache_entry.flags.alpha)
 	d = DP;
    return copy_rel_gfx_span_func_cpu(s, m, c, d);
 }
 
 static RGBA_Gfx_Func
-op_copy_rel_mask_color_span_get(DATA32 col, RGBA_Image *dst, int pixels)
+op_copy_rel_mask_color_span_get(DATA32 col, RGBA_Image *dst, int pixels __UNUSED__)
 {
    int  s = SP_N, m = SM_AS, c = SC_AN, d = DP;
 
    if (dst)
-	dst->flags |= RGBA_IMAGE_HAS_ALPHA;
+	dst->cache_entry.flags.alpha = 1;
    if ((col >> 24) < 255)
 	c = SC;
    if (col == ((col >> 24) * 0x01010101))
@@ -482,13 +542,13 @@ op_copy_rel_mask_color_span_get(DATA32 col, RGBA_Image *dst, int pixels)
 }
 
 static RGBA_Gfx_Func
-op_copy_rel_pixel_mask_span_get(RGBA_Image *src, RGBA_Image *dst, int pixels)
+op_copy_rel_pixel_mask_span_get(RGBA_Image *src, RGBA_Image *dst, int pixels __UNUSED__)
 {
    int  s = SP_AN, m = SM_AS, c = SC_N, d = DP;
 
    if (dst)
-	dst->flags |= RGBA_IMAGE_HAS_ALPHA;
-   if (src && (src->flags & RGBA_IMAGE_HAS_ALPHA))
+	dst->cache_entry.flags.alpha = 1;
+   if (src && src->cache_entry.flags.alpha)
 	s = SP;
    return copy_rel_gfx_span_func_cpu(s, m, c, d);
 }
@@ -506,6 +566,14 @@ copy_rel_gfx_pt_func_cpu(int s, int m, int c, int d)
       if (func) return func;
     }
 #endif
+#ifdef BUILD_NEON
+   if (evas_common_cpu_has_feature(CPU_FEATURE_NEON))
+    {
+      cpu = CPU_NEON;
+      func = op_copy_rel_pt_funcs[s][m][c][d][cpu];
+      if (func) return func;
+    }
+#endif
 #ifdef BUILD_C
    cpu = CPU_C;
    func = op_copy_rel_pt_funcs[s][m][c][d][cpu];
@@ -515,21 +583,22 @@ copy_rel_gfx_pt_func_cpu(int s, int m, int c, int d)
 }
 
 static RGBA_Gfx_Pt_Func
-op_copy_rel_pixel_pt_get(int src_flags, RGBA_Image *dst)
+op_copy_rel_pixel_pt_get(Image_Entry_Flags src_flags, RGBA_Image *dst)
 {
    int  s = SP_AN, m = SM_N, c = SC_N, d = DP_AN;
 
-   if (src_flags & RGBA_IMAGE_HAS_ALPHA)
+   if (src_flags.alpha)
      {
 	if (dst)
-	   dst->flags |= RGBA_IMAGE_HAS_ALPHA;
+	   dst->cache_entry.flags.alpha = 1;
 	s = SP;
      }
-   if (dst && (dst->flags & RGBA_IMAGE_HAS_ALPHA))
+   if (dst && dst->cache_entry.flags.alpha)
 	d = DP;
    return copy_rel_gfx_pt_func_cpu(s, m, c, d);
 }
 
+/* XXX: not used
 static RGBA_Gfx_Pt_Func
 op_copy_rel_color_pt_get(DATA32 col, RGBA_Image *dst)
 {
@@ -538,40 +607,41 @@ op_copy_rel_color_pt_get(DATA32 col, RGBA_Image *dst)
    if ((col >> 24) < 255)
      {
 	if (dst)
-	   dst->flags |= RGBA_IMAGE_HAS_ALPHA;
+	   dst->cache_entry.flags.alpha = 1;
 	c = SC;
      }
    if (col == ((col >> 24) * 0x01010101))
 	c = SC_AA;
    if (col == 0xffffffff)
 	c = SC_N;
-   if (dst && (dst->flags & RGBA_IMAGE_HAS_ALPHA))
+   if (dst && dst->cache_entry.flags.alpha)
 	d = DP;
    return copy_rel_gfx_pt_func_cpu(s, m, c, d);
 }
+*/
 
 static RGBA_Gfx_Pt_Func
-op_copy_rel_pixel_color_pt_get(int src_flags, DATA32 col, RGBA_Image *dst)
+op_copy_rel_pixel_color_pt_get(Image_Entry_Flags src_flags, DATA32 col, RGBA_Image *dst)
 {
    int  s = SP_AN, m = SM_N, c = SC_AN, d = DP_AN;
 
-   if (src_flags & RGBA_IMAGE_HAS_ALPHA)
+   if (src_flags.alpha)
      {
 	if (dst)
-	   dst->flags |= RGBA_IMAGE_HAS_ALPHA;
+	   dst->cache_entry.flags.alpha = 1;
 	s = SP;
      }
    if ((col >> 24) < 255)
      {
 	if (dst)
-	   dst->flags |= RGBA_IMAGE_HAS_ALPHA;
+	   dst->cache_entry.flags.alpha = 1;
 	c = SC;
      }
    if (col == ((col >> 24) * 0x01010101))
 	c = SC_AA;
    if (col == 0xffffffff)
 	c = SC_N;
-   if (dst && (dst->flags & RGBA_IMAGE_HAS_ALPHA))
+   if (dst && dst->cache_entry.flags.alpha)
 	d = DP;
    return copy_rel_gfx_pt_func_cpu(s, m, c, d);
 }
@@ -582,7 +652,7 @@ op_copy_rel_mask_color_pt_get(DATA32 col, RGBA_Image *dst)
    int  s = SP_N, m = SM_AS, c = SC_AN, d = DP;
 
    if (dst)
-	dst->flags |= RGBA_IMAGE_HAS_ALPHA;
+	dst->cache_entry.flags.alpha = 1;
    if ((col >> 24) < 255)
 	c = SC;
    if (col == ((col >> 24) * 0x01010101))
@@ -593,13 +663,13 @@ op_copy_rel_mask_color_pt_get(DATA32 col, RGBA_Image *dst)
 }
 
 static RGBA_Gfx_Pt_Func
-op_copy_rel_pixel_mask_pt_get(int src_flags, RGBA_Image *dst)
+op_copy_rel_pixel_mask_pt_get(Image_Entry_Flags src_flags, RGBA_Image *dst)
 {
    int  s = SP_AN, m = SM_AS, c = SC_N, d = DP;
 
    if (dst)
-	dst->flags |= RGBA_IMAGE_HAS_ALPHA;
-   if (src_flags & RGBA_IMAGE_HAS_ALPHA)
+	dst->cache_entry.flags.alpha = 1;
+   if (src_flags.alpha)
 	s = SP;
    return copy_rel_gfx_pt_func_cpu(s, m, c, d);
 }
