@@ -589,7 +589,7 @@ START_TEST(evas_textblock_cursor)
         evas_textblock_cursor_word_end(cur);
         fail_if(18 != evas_textblock_cursor_pos_get(cur));
         evas_textblock_cursor_word_end(cur);
-        fail_if(18 != evas_textblock_cursor_pos_get(cur));
+        fail_if(21 != evas_textblock_cursor_pos_get(cur));
 
         /* Bug with 1 char word separators at paragraph start. */
         evas_object_textblock_text_markup_set(tb, "=test");
@@ -598,6 +598,27 @@ START_TEST(evas_textblock_cursor)
         fail_if(1 != evas_textblock_cursor_pos_get(cur));
      }
 
+   /* Make sure coords are correct for ligatures */
+     {
+        evas_object_textblock_text_markup_set(tb, "fi<br/>fii");
+
+        for (i = 0 ; i < 2 ; i++)
+          {
+             evas_textblock_cursor_pen_geometry_get(cur, NULL, NULL, &w, NULL);
+             ck_assert_int_eq(w, 3);
+             evas_textblock_cursor_char_next(cur);
+          }
+
+        evas_textblock_cursor_char_next(cur);
+
+        for (i = 0 ; i < 3 ; i++)
+          {
+             evas_textblock_cursor_pen_geometry_get(cur, NULL, NULL, &w, NULL);
+             ck_assert_int_eq(w, 3);
+             evas_textblock_cursor_char_next(cur);
+          }
+     }
+
    END_TB_TEST();
 }
 END_TEST
@@ -829,6 +850,13 @@ START_TEST(evas_textblock_format_removal)
    fnode = evas_textblock_node_format_first_get(tb);
    fail_if (fnode);
 
+   /* Range delete with empty paragraphs. */
+   evas_object_textblock_text_markup_set(tb, "<ps/><ps/><ps/><ps/><ps/>");
+   evas_textblock_cursor_pos_set(cur, 2);
+   evas_textblock_cursor_pos_set(main_cur, 3);
+   evas_textblock_cursor_range_delete(cur, main_cur);
+   ck_assert_str_eq(evas_object_textblock_text_markup_get(tb), "<ps/><ps/><ps/><ps/>");
+
    /* Verify fmt position and REP_CHAR positions are the same */
    evas_object_textblock_text_markup_set(tb,
          "This is<ps/>an <item absize=93x152 vsize=ascent></>a.");
@@ -995,7 +1023,7 @@ START_TEST(evas_textblock_items)
    buf = "This is an <item absize=93x152 vsize=full></>.";
    evas_object_textblock_text_markup_set(tb, buf);
    evas_object_textblock_size_formatted_get(tb, &w, &h);
-   fail_if((w < 93) || (h != 152));
+   fail_if((w < 93) || (h < 153));
    evas_textblock_cursor_pos_set(cur, 11);
    evas_textblock_cursor_format_item_geometry_get(cur, NULL, NULL, &w, &h);
    fail_if((w != 93) || (h != 152));
@@ -1003,7 +1031,7 @@ START_TEST(evas_textblock_items)
    buf = "This is an <item absize=93x152 vsize=ascent></>.";
    evas_object_textblock_text_markup_set(tb, buf);
    evas_object_textblock_size_formatted_get(tb, &w, &h);
-   fail_if((w < 93) || (h <= 152));
+   fail_if((w < 93) || (h <= 153));
    evas_textblock_cursor_pos_set(cur, 11);
    evas_textblock_cursor_format_item_geometry_get(cur, NULL, NULL, &w, &h);
    fail_if((w != 93) || (h != 152));
@@ -1012,7 +1040,7 @@ START_TEST(evas_textblock_items)
    buf = "This is an <item size=93x152 vsize=full></>.";
    evas_object_textblock_text_markup_set(tb, buf);
    evas_object_textblock_size_formatted_get(tb, &w, &h);
-   fail_if((w < 93) || (h != 152));
+   fail_if((w < 93) || (h < 153));
    evas_textblock_cursor_pos_set(cur, 11);
    evas_textblock_cursor_format_item_geometry_get(cur, NULL, NULL, &w, &h);
    fail_if((w != 93) || (h != 152));
@@ -1020,7 +1048,7 @@ START_TEST(evas_textblock_items)
    buf = "This is an <item size=93x152 vsize=ascent></>.";
    evas_object_textblock_text_markup_set(tb, buf);
    evas_object_textblock_size_formatted_get(tb, &w, &h);
-   fail_if((w < 93) || (h <= 152));
+   fail_if((w < 93) || (h <= 153));
    evas_textblock_cursor_pos_set(cur, 11);
    evas_textblock_cursor_format_item_geometry_get(cur, NULL, NULL, &w, &h);
    fail_if((w != 93) || (h != 152));
@@ -1029,7 +1057,7 @@ START_TEST(evas_textblock_items)
    buf = "This is an <item size=93x152 vsize=full></>.";
    evas_object_textblock_text_markup_set(tb, buf);
    evas_object_textblock_size_formatted_get(tb, &w, &h);
-   fail_if((w < (2 * 93)) || (h != (2 * 152)));
+   fail_if((w < (2 * 93)) || (h < (2 * 154)));
    evas_textblock_cursor_pos_set(cur, 11);
    evas_textblock_cursor_format_item_geometry_get(cur, NULL, NULL, &w, &h);
    fail_if((w != (2 * 93)) || (h != (2 * 152)));
@@ -1040,7 +1068,7 @@ START_TEST(evas_textblock_items)
    buf = "This is an <item size=93x152 vsize=ascent></>.";
    evas_object_textblock_text_markup_set(tb, buf);
    evas_object_textblock_size_formatted_get(tb, &w, &h);
-   fail_if((w < (2 * 93)) || (h <= (2 * 152)));
+   fail_if((w < (2 * 93)) || (h <= (2 * 154)));
    evas_textblock_cursor_pos_set(cur, 11);
    evas_textblock_cursor_format_item_geometry_get(cur, NULL, NULL, &w, &h);
    fail_if((w != (2 * 93)) || (h != (2 * 152)));
@@ -1052,10 +1080,10 @@ START_TEST(evas_textblock_items)
    buf = "This is an <item relsize=93x152 vsize=full></>.";
    evas_object_textblock_text_markup_set(tb, buf);
    evas_object_textblock_size_formatted_get(tb, &w, &h);
-   fail_if((w >= 93) || (h >= 152));
+   fail_if((w >= 93) || (h >= 153));
    evas_textblock_cursor_pos_set(cur, 11);
    evas_textblock_cursor_format_item_geometry_get(cur, NULL, NULL, &w, &ih);
-   fail_if((w > 90) || (h != ih));
+   fail_if((w > 90) || (h <= ih));
 
    buf = "This is an <item relize=93x152 vsize=ascent></>.";
    evas_object_textblock_text_markup_set(tb, buf);
@@ -1287,6 +1315,16 @@ START_TEST(evas_textblock_wrapping)
    evas_object_textblock_size_formatted_get(tb, &w, &h);
    fail_if(w > (nw / 2));
 
+   /* Word wrap ending with whites. */
+   evas_object_resize(tb, 322, 400);
+   evas_object_textblock_text_markup_set(tb, "<wrap=word>This is an example text that should break at the end aaa     ");
+
+   evas_textblock_cursor_paragraph_last(cur);
+   Evas_Coord cx, cy, cw, ch;
+   evas_textblock_cursor_text_prepend(cur, " ");
+   fail_if(-1 == evas_textblock_cursor_geometry_get(cur, &cx, &cy, &cw, &ch,
+            NULL, EVAS_TEXTBLOCK_CURSOR_BEFORE));
+
    END_TB_TEST();
 }
 END_TEST
@@ -1368,6 +1406,11 @@ START_TEST(evas_textblock_geometries)
    fail_if((tr->x != tr2->x) || (tr->y != tr2->y) || (tr->w != tr2->w) ||
          (tr->h != tr2->h));
 
+   EINA_LIST_FREE(rects, tr)
+      free(tr);
+   EINA_LIST_FREE(rects2, tr2)
+      free(tr2);
+
    /* Multiline range */
    evas_textblock_cursor_pos_set(cur, 0);
    evas_textblock_cursor_pos_set(main_cur, 14);
@@ -1401,6 +1444,35 @@ START_TEST(evas_textblock_geometries)
    tr2 = eina_list_data_get(eina_list_next(rects));
    fail_if(tr->y >= tr2->y);
 
+   EINA_LIST_FREE(rects, tr)
+      free(tr);
+   EINA_LIST_FREE(rects2, tr2)
+      free(tr2);
+
+   /* Same run different scripts */
+   evas_object_textblock_text_markup_set(tb, "עבריתenglishрусскийעברית");
+
+   evas_textblock_cursor_pos_set(cur, 3);
+   evas_textblock_cursor_pos_set(main_cur, 7);
+   rects = evas_textblock_cursor_range_geometry_get(cur, main_cur);
+
+   fail_if(eina_list_count(rects) != 2);
+
+   EINA_LIST_FREE(rects, tr)
+      free(tr);
+
+   /* Same run different styles */
+   evas_object_textblock_text_markup_set(tb, "test<b>test2</b>test3");
+
+   evas_textblock_cursor_pos_set(cur, 3);
+   evas_textblock_cursor_pos_set(main_cur, 11);
+   rects = evas_textblock_cursor_range_geometry_get(cur, main_cur);
+
+   fail_if(eina_list_count(rects) != 3);
+
+   EINA_LIST_FREE(rects, tr)
+      free(tr);
+
    END_TB_TEST();
 }
 END_TEST
@@ -1704,6 +1776,41 @@ START_TEST(evas_textblock_text_getters)
         free(tmp);
      }
 
+   /* complex markup set/get */
+     {
+        const char *text =
+           "This is an entry widget in this window that<ps/>"
+           "uses markup <b>like this</> for styling and<ps/>"
+           "formatting <em>like this</>, as well as<ps/>"
+           "<a href=X><link>links in the text</></a>, so enter text<ps/>"
+           "in here to edit it. By the way, links are<ps/>"
+           "called <a href=anc-02>Anchors</a> so you will need<ps/>"
+           "to refer to them this way.<ps/>"
+           "<ps/>"
+
+           "Also you can stick in items with (relsize + ascent): "
+           "<item relsize=16x16 vsize=ascent href=emoticon/evil-laugh></item>"
+           " (full) "
+           "<item relsize=16x16 vsize=full href=emoticon/guilty-smile></item>"
+           " (to the left)<ps/>"
+
+           "Also (size + ascent): "
+           "<item size=16x16 vsize=ascent href=emoticon/haha></item>"
+           " (full) "
+           "<item size=16x16 vsize=full href=emoticon/happy-panting></item>"
+           " (before this)<ps/>"
+
+           "And as well (absize + ascent): "
+           "<item absize=64x64 vsize=ascent href=emoticon/knowing-grin></item>"
+           " (full) "
+           "<item absize=64x64 vsize=full href=emoticon/not-impressed></item>"
+           " or even paths to image files on disk too like: "
+           "<item absize=96x128 vsize=full href=file://bla/images/sky_01.jpg></item>"
+           " ... end.";
+        evas_object_textblock_text_markup_set(tb, text);
+        ck_assert_str_eq(text, evas_object_textblock_text_markup_get(tb));
+     }
+
    END_TB_TEST();
 }
 END_TEST
@@ -1950,6 +2057,16 @@ START_TEST(evas_textblock_formats)
    fail_if(strcmp(evas_textblock_cursor_content_get(cur), "<item>"));
    fail_if(!evas_textblock_cursor_format_is_visible_get(cur));
 
+   evas_object_textblock_text_markup_set(tb, "abc<br/>def");
+   evas_textblock_cursor_pos_set(cur, 3);
+   evas_object_textblock_text_markup_prepend(cur, "<b></b>");
+   ck_assert_str_eq(evas_object_textblock_text_markup_get(tb), "abc<b></b><br/>def");
+   evas_object_textblock_text_markup_set(tb, "abc<br/>def");
+   evas_textblock_cursor_pos_set(cur, 2);
+   evas_object_textblock_text_markup_prepend(cur, "<b></b>");
+   ck_assert_str_eq(evas_object_textblock_text_markup_get(tb), "ab<b></b>c<br/>def");
+
+
    END_TB_TEST();
 }
 END_TEST
@@ -2121,11 +2238,11 @@ START_TEST(evas_textblock_escaping)
 
    const char *buf = "This &middot; is";
    evas_object_textblock_text_markup_set(tb, buf);
-   fail_if(strcmp(evas_object_textblock_text_markup_get(tb), buf));
+   fail_if(strcmp(evas_object_textblock_text_markup_get(tb), "This \xc2\xb7 is"));
 
    buf = "This &nbsp; is";
    evas_object_textblock_text_markup_set(tb, buf);
-   fail_if(strcmp(evas_object_textblock_text_markup_get(tb), buf));
+   fail_if(strcmp(evas_object_textblock_text_markup_get(tb), "This \xc2\xa0 is"));
 
    END_TB_TEST();
 }
@@ -2136,21 +2253,30 @@ START_TEST(evas_textblock_size)
    START_TB_TEST();
    Evas_Coord w, h, h2, nw, nh;
    const char *buf = "This is a <br/> test.<br/>גם בעברית";
+
+   /* Empty textblock */
+   evas_object_textblock_size_formatted_get(tb, &w, &h);
+   evas_object_textblock_size_native_get(tb, &nw, &nh);
+   ck_assert_int_eq(w, nw);
+   ck_assert_int_eq(h, nh);
+   fail_if(w != 0);
+
+
    /* When wrapping is off, native size should be the same as formatted
     * size */
 
+   evas_object_textblock_text_markup_set(tb, buf);
    evas_object_textblock_size_formatted_get(tb, &w, &h);
    evas_object_textblock_size_native_get(tb, &nw, &nh);
    fail_if((w != nw) || (h != nh));
-   fail_if(w != 0);
 
    evas_object_textblock_text_markup_set(tb, "a<br/>a");
    evas_object_textblock_size_formatted_get(tb, &w, &h2);
    evas_object_textblock_size_native_get(tb, &nw, &nh);
    fail_if((w != nw) || (h2 != nh));
 
-   /* Two lines == double the height */
-   fail_if(h * 2 != h2);
+   /* Two lines != double the height */
+   fail_if(h * 2 == h2);
 
    evas_object_textblock_text_markup_set(tb, buf);
 
